use argh::FromArgs;

use crate::fx::Features;

#[derive(FromArgs)]
/// navOS Installer
pub struct NavinstallArgs {
    #[argh(subcommand)]
    pub cmd: NavinstallCommands,
}

#[derive(FromArgs)]
#[argh(subcommand)]
pub enum NavinstallCommands {
    CreateISO(CreateISOCommand),
    Install(InstallCommand),
    CreateTar(CreateTarCommand),
    CreateImage(CreateImageCommand),
    Feature(FeatureCommand),
}

#[derive(FromArgs)]
#[argh(subcommand, name = "create-iso")]
/// Create a new installation medium ISO
pub struct CreateISOCommand {
    #[argh(switch)]
    /// create ISO with just terminal
    pub without_gui: bool,

    #[argh(switch)]
    /// create ISO on disk
    pub no_tmp: bool,

    #[argh(option)]
    /// create ISO with this keyboard layout
    pub kb_layout: Option<String>,

    #[argh(option)]
    /// create ISO with this keyboard layout variant
    pub kb_variant: Option<String>,

    #[argh(option)]
    /// change the system user
    pub user: Option<String>,

    #[argh(option)]
    /// change the system users password
    pub pass: Option<String>,

    #[argh(option)]
    /// change the system user UID
    pub uid: Option<u16>,

    #[argh(option)]
    /// include a systemd unit
    pub unit: Vec<String>,

    #[argh(option)]
    /// create ISO which automatically installs <CONFIG> upon boot.
    pub install: Option<String>,
}

#[derive(FromArgs)]
#[argh(subcommand, name = "install")]
/// Install a system according to configuration
pub struct InstallCommand {
    #[argh(switch, short = 'f')]
    /// install without confirming config
    pub force: bool,

    #[argh(positional)]
    /// config file
    pub config: String,
}

#[derive(FromArgs)]
#[argh(subcommand, name = "create-tar")]
/// Create a container rootfs
pub struct CreateTarCommand {
    #[argh(positional)]
    /// rootfs dir
    pub dir: String,
}

#[derive(FromArgs)]
#[argh(subcommand, name = "create-img")]
/// Create an install on a disk image for VMs or embedded devices
pub struct CreateImageCommand {
    #[argh(switch)]
    /// use modern disk format
    pub gpt: bool,

    #[argh(positional)]
    /// config file
    pub config: String,

    #[argh(positional)]
    /// image file
    pub image: String,
}

#[derive(FromArgs)]
#[argh(subcommand, name = "fx")]
/// Enable or disable features
pub struct FeatureCommand {
    #[argh(subcommand)]
    pub cmd: Features,
}
