use argh::FromArgs;

use crate::{
    linux::{arch_chroot, systemd_service_enable},
    pkg::install_pkgs,
    print_status,
};

#[derive(FromArgs)]
#[argh(subcommand, name = "firewall")]
/// Install firewall
pub struct FirewallFeature {
    #[argh(switch)]
    /// allow SSH
    pub ssh: bool,
}

/// Setup UFW
pub fn setup_firewall(ssh: bool) {
    print_status("Enabling firewall");
    install_pkgs(&["ufw"]);
    systemd_service_enable("ufw.service");

    arch_chroot(&["ufw", "default", "deny"], None, false);

    if ssh {
        arch_chroot(&["ufw", "allow", "22/tcp"], None, false);

        arch_chroot(&["ufw", "limit", "ssh"], None, false);
    }

    arch_chroot(&["ufw", "enable"], None, false);
}
