use crate::{linux::arch_chroot_at, print_status};

pub fn setup_navos(root: &str) {
    let root = std::path::PathBuf::from(root);
    // pacman.conf
    print_status("Copying pacman.conf");
    std::fs::copy("/etc/pacman.conf", root.join("etc").join("pacman.conf")).unwrap();

    // import keys
    print_status("Importing pkg keys");
    std::fs::write(
        root.join("usr")
            .join("share")
            .join("pacman")
            .join("keyrings")
            .join("navos.gpg"),
        include_str!("../../navos.gpg"),
    )
    .unwrap();

    arch_chroot_at(
        root.display().to_string().as_str(),
        &[
            "pacman-key",
            "--add",
            "/usr/share/pacman/keyrings/navos.gpg",
        ],
        None,
        false,
    );

    arch_chroot_at(
        root.display().to_string().as_str(),
        &[
            "pacman-key",
            "--lsign-key",
            "778D9D7E5B6AC3762BB5541FEE446EC749C4AE00",
        ],
        None,
        false,
    );

    // remove os-release
    print_status("Removing os-release");
    let _ = std::fs::remove_file(root.join("etc").join("os-release"));
}
